import { appendHeaders } from "@settlemint/sdk-utils/http";
import { ensureServer } from "@settlemint/sdk-utils/runtime";
import { ApplicationAccessTokenSchema, UrlOrPathSchema, validate } from "@settlemint/sdk-utils/validation";
import { initGraphQLTada, readFragment } from "gql.tada";
import { GraphQLClient } from "graphql-request";
import { z } from "zod/v4";

//#region src/blockscout.ts
/**
* Schema for validating client options for the Blockscout client.
*/
const ClientOptionsSchema = z.object({
	instance: UrlOrPathSchema,
	accessToken: ApplicationAccessTokenSchema.optional()
});
/**
* Creates a Blockscout GraphQL client with proper type safety using gql.tada
*
* @param options - Configuration options for the client
* @param clientOptions - Optional GraphQL client configuration options
* @returns An object containing the GraphQL client and initialized gql.tada function
* @throws Will throw an error if the options fail validation
* @example
* import { createBlockscoutClient } from '@settlemint/sdk-blockscout';
* import type { introspection } from "@schemas/blockscout-env";
* import { createLogger, requestLogger } from '@settlemint/sdk-utils/logging';
*
* const logger = createLogger();
*
* const { client, graphql } = createBlockscoutClient<{
*   introspection: introspection;
*   disableMasking: true;
*   scalars: {
*     AddressHash: string;
*     Data: string;
*     DateTime: string;
*     Decimal: string;
*     FullHash: string;
*     Json: string;
*     NonceHash: string;
*     Wei: string;
*   };
* }>({
*   instance: process.env.SETTLEMINT_BLOCKSCOUT_ENDPOINT,
*   accessToken: process.env.SETTLEMINT_ACCESS_TOKEN
* }, {
*   fetch: requestLogger(logger, "blockscout", fetch) as typeof fetch,
* });
*
* // Making GraphQL queries
* const query = graphql(`
*   query GetTransaction($hash: String!) {
*     transaction(hash: $hash) {
*       hash
*       blockNumber
*       value
*       gasUsed
*     }
*   }
* `);
*
* const result = await client.request(query, {
*   hash: "0x123abc..."
* });
*/
function createBlockscoutClient(options, clientOptions) {
	ensureServer();
	const validatedOptions = validate(ClientOptionsSchema, options);
	const graphql = initGraphQLTada();
	const fullUrl = new URL(validatedOptions.instance).toString();
	return {
		client: new GraphQLClient(fullUrl, {
			...clientOptions,
			headers: appendHeaders(clientOptions?.headers, { "x-auth-token": validatedOptions.accessToken })
		}),
		graphql
	};
}

//#endregion
export { ClientOptionsSchema, createBlockscoutClient, readFragment };
//# sourceMappingURL=blockscout.js.map